@@ -62,16 +62,37 @@ class MinioBackend(BackendBase):
 
                 if os.path.isfile(download_path):
                     os.remove(download_path)
+
+                self.create_dir_if_not_exists(download_path)
                 wget.download(url, download_path)
                 return True, download_path
         except Exception as e:
+            traceback.print_exc()
             if tries >= 3:
                 return False, str(e)
             else:
                 return self.get(download_path, bucket, bucket_name, tries+1)
 
-    async def get_async(self, download_path, bucket, bucket_name):
-        return self.get(download_path, bucket, bucket_name)
+    async def get_async(self, download_path, bucket, bucket_name, tries=0):
+        try:
+            if tries >= 3:
+                return False, '下载出错'
+            else:
+                url = 'http://{}/{}/{}'.format(self.domain, self.default_bucket, '{}_{}'.format(bucket, bucket_name))
+                print('downloading {} -> {}'.format(url, download_path))
+
+                if os.path.isfile(download_path):
+                    os.remove(download_path)
+
+                self.create_dir_if_not_exists(download_path)
+                await self.download_file(url, download_path)
+                return True, download_path
+        except Exception as e:
+            traceback.print_exc()
+            if tries >= 3:
+                return False, str(e)
+            else:
+                return await self.get_async(download_path, bucket, bucket_name, tries+1)
 
 
             
