@@ -126,8 +126,8 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                     }, expired=60)
 
 
-def put_to_cloud(task_id, file_path, bucket, bucket_name, tries=0):
-    ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name)
+def put_to_cloud(task_id, file_path, bucket, bucket_name, refresh=False, tries=0):
+    ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name, refresh=refresh)
     if ret:
         print('fget -> uploaded to cloud')
         cache_engine.cache(task_id, {
@@ -143,7 +143,7 @@ def put_to_cloud(task_id, file_path, bucket, bucket_name, tries=0):
             }, expired=60)
         else:
             print('fget -> retry put to cloud') 
-            put_to_cloud(task_id, file_path, bucket, bucket_name, tries+1)
+            put_to_cloud(task_id, file_path, bucket, bucket_name, refresh=refresh, tries=tries+1)
 
 @task_deco('fs_get', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ)
 async def file_transfer_get(bucket, bucket_name, refresh='no'):
@@ -165,7 +165,7 @@ async def file_transfer_get(bucket, bucket_name, refresh='no'):
                 return
         
 
-        put_to_cloud(task_id, file_path, bucket, bucket_name)
+        put_to_cloud(task_id, file_path, bucket, bucket_name, refresh=refresh=='yes')
     except Exception as e:
         traceback.print_exc()
     
@@ -209,13 +209,14 @@ async def extra_tasks():
             if affected_records > 0:
                 print('data cleaned')
 
-            if is_time_in_range('04:00', '06:00'):
+            if is_time_in_range('02:00', '04:00'):
                 if cache_engine.get_cache('hmfs_cleanup'):
                     continue
                 await hmfs_client.cleanup_cloud()
                 cache_engine.cache('hmfs_cleanup', 1, expired=7200)
 
                 shutil.rmtree(cache_path, ignore_errors=True)
+                os.mkdir(cache_path)
         except:
             traceback.print_exc()
         finally:
