@@ -2,6 +2,7 @@
 import traceback
 from gnsq import Producer, Consumer, Message, NsqdHTTPClient
 from ansq import open_connection
+from ansq.tcp.connection import ConnectionStatus
 import asyncio
 import orjson
 import time
@@ -20,30 +21,34 @@ class MQManager(Singleton):
         if init:
             self._init()
         self._inited = True
-
+    
     def _init(self):
+        self.addr = '{}:{}'.format(self.host, self.port)
+        self.producer = Producer(nsqd_tcp_addresses=[self.addr])
+        self.producer.start()
+
+    async def _init_async(self):
         if self.async_mq:
-            self.mq = asyncio.get_event_loop().run_until_complete(open_connection(self.host, self.port))
-        else:
-            self.addr = '{}:{}'.format(self.host, self.port)
-            self.producer = Producer(nsqd_tcp_addresses=[self.addr])
-            self.producer.start()
-        self.inited = True
+            self.mq = await open_connection(self.host, self.port)
 
     def close(self):
         if not self.async_mq:
             self.close_producer()
 
-    async def close(self):
-        if self.async_mq:
-            await self.mq.close()
+    async def close_async(self):
+        try:
+            if self.async_mq:
+                await self.mq.close()
+                del self.mq
+        except:
+            traceback.print_exc()
 
     async def get_mq_conn(self):
         if not hasattr(self, 'mq'):
             self.mq = await open_connection(self.host, self.port)
         
-        if not self.mq.status.is_connected:
-            del self.mq
+        if not self.mq.status == ConnectionStatus.CONNECTED:
+            await self.close_async()
             return await self.get_mq_conn()
         else:
             return self.mq
