@@ -307,7 +307,7 @@ class XRedisAsync(Singleton):
     async def __release_conn(self):
         if hasattr(self, 'conn'):
             print('释放连接')
-            await self.conn.quit()
+            await self.conn.close()
             del self.conn
     
     async def _make_conn(self):
